#!/bin/sh
# Shell script to install libdvdcss under Debian GNU Linux
# Many DVDs use css for encryption.  To play these discs, a special library 
# is needed to decode them, libdvdcss.  Due to legal problems, Debian and most
# Linux distibutions cannot distribute libdvdcss
# Use this shell script to install the libdvdcss under DEBIAN GNU/Linux
# --------------------------------------------------------------------------
# Refer url for more info:
# Copyright info -  http://www.dtek.chalmers.se/~dvd/
# -------------------------------------------------------------------------
# This script is part of nixCraft shell script collection (NSSC)
# Visit http://bash.cyberciti.biz/ for more information.
# -------------------------------------------------------------------------

set -e

if [ ! -w /etc/passwd ]; then
    echo "Super-user privileges are required.  Please run this with 'sudo'." >&2
    exit 1
fi

site=http://packages.medibuntu.org/pool/free/libd/libdvdcss/
arch=$(dpkg --print-installation-architecture)

soname=2
uversion=1.2.10
uversion_old=1.2.9
available="i386 amd64 powerpc lpia"
available_old="sparc"
version=${uversion}-0.2medibuntu1
version_old=${uversion_old}-2medibuntu4

if ! type wget > /dev/null ; then
    echo "Install wget and run this script again" >&2
    exit 1
fi

CSSTMP=$(mktemp -t -d dvdcss-XXXXXX)
for a in $available; do
    if [  "$a" = "$arch" ]; then
	wget ${site}libdvdcss${soname}_${version}_${arch}.deb -O "$CSSTMP"/libdvdcss.deb
	dpkg -i "$CSSTMP"/libdvdcss.deb
	exit $?
    fi
done
for a in $available_old; do
    if [  "$a" = "$arch" ]; then
	wget ${site}libdvdcss${soname}_${version_old}_${arch}.deb -O "$CSSTMP"/libdvdcss.deb
	dpkg -i "$CSSTMP"/libdvdcss.deb
	exit $?
    fi
done

echo "No prebuilt binary available.  Will try to build and install it."
echo "You need to have build-essential, debhelper and fakeroot installed."
echo "If not, interrupt now, install them and rerun this script."
echo ""
echo "This is higly experimental, look out for what happens below."
echo "If you want to stop, interrupt now (control-c), else press"
echo "return to proceed"
read dum

if ! type dh_testdir > /dev/null || ! type fakeroot > /dev/null; then
    echo "Attempting to install build-essential, debhelper and fakeroot..." >&2
    apt-get update && apt-get install build-essential debhelper fakeroot
fi

if ! type dh_testdir > /dev/null || ! type fakeroot > /dev/null || 
! type make > /dev/null ; then
    echo "Failed to install build-essential, debhelper and fakeroot, exiting now." >&2
    exit 1
fi

cd "$CSSTMP"
wget ${site}libdvdcss_${uversion}.orig.tar.gz
wget ${site}libdvdcss_${version}.diff.gz
wget ${site}libdvdcss_${version}.dsc
dpkg-source -x libdvdcss_${version}.dsc
cd libdvdcss-${uversion}
fakeroot ./debian/rules binary
dpkg -i ../libdvdcss${soname}_${version}_${arch}.deb
